@@ -1,7 +1,11 @@
 from .htmx import Htmx  # noqa
 from .htmx_extension import HtmxExtension  # noqa
-from .start_project import StartProject  # noqa
-from .rm_migrations import RmMigrations  # noqa
-from .work import Work  # noqa
-from .sync_dotenv import SyncDotenv  # noqa
+from .install_crud_utils import InstallCrudUtils  # noqa
 from .model_crud import ModelCRUD  # noqa
+from .reset_migrations import ResetMigrations  # noqa
+from .rm_migrations import RmMigrations  # noqa
+from .setup_admin import SetupAdmin  # noqa
+from .start_app import StartApp  # noqa
+from .start_project import StartProject  # noqa
+from .sync_dotenv import SyncDotenv  # noqa
+from .work import Work  # noqa
