@@ -1,9 +1,9 @@
 from pathlib import Path
 from typing import Annotated
-from typing import Optional
 
 import cappa
 import httpx
+from falco.utils import get_pyproject_file
 from falco.utils import network_request_with_progress
 from falco.utils import simple_progress
 from rich import print as rich_print
@@ -11,22 +11,24 @@ from rich.console import Console
 from rich.panel import Panel
 from rich.table import Table
 
+from .htmx import Htmx
+
 REGISTRY_URL = "https://htmx-extensions.oluwatobi.dev/extensions.json"
 
 
 @cappa.command(help="Download one of htmx extensions.", name="htmx-ext")
 class HtmxExtension:
     name: Annotated[
-        Optional[str],
+        str | None,
         cappa.Arg(
-            default="",
+            default=None,
             help="The name of the extension to download.",
         ),
     ]
     output: Annotated[
-        Path,
+        Path | None,
         cappa.Arg(
-            default=Path(),
+            default=None,
             help="The directory to write the downloaded file to.",
             short="-o",
             long="--output",
@@ -44,17 +46,16 @@ class HtmxExtension:
         extension = extensions.get(self.name)
 
         if not extension:
-            raise cappa.Exit(f"Could not find {self.name} extension.", code=1)
+            msg = f"Could not find {self.name} extension."
+            raise cappa.Exit(msg, code=1)
 
         with simple_progress(f"Downloading {self.name} extension"):
             download_url = extension.get("download_url")
             response = httpx.get(download_url, follow_redirects=True)
 
-            if str(self.output).endswith(".js"):
-                self.output.write_text(response.text)
-            else:
-                self.output.mkdir(parents=True, exist_ok=True)
-                (self.output / f"{self.name}.js").write_text(response.text)
+            output_file = self.resolve_filepath()
+            output_file.parent.mkdir(parents=True, exist_ok=True)
+            output_file.write_text(response.text)
 
         rich_print(
             Panel(
@@ -63,6 +64,23 @@ class HtmxExtension:
             )
         )
 
+    def resolve_filepath(self) -> Path:
+        try:
+            pyproject_path = get_pyproject_file()
+        except cappa.Exit:
+            pyproject_path = None
+
+        if self.output:
+            filepath = self.output if self.output.name.endswith(".js") else self.output / f"{self.name}.js"
+        elif self.output is None and pyproject_path:
+            htmx_config = Htmx.read_from_config(pyproject_path=pyproject_path)
+            htmx_filepath, _ = htmx_config
+            filepath = htmx_filepath.parent / f"{self.name}.js"
+        else:
+            filepath = Path(f"{self.name}.js")
+
+        return filepath
+
     def list_all(self):
         extensions = self.read_registry()
 
