@@ -2,11 +2,13 @@ from pathlib import Path
 from typing import Annotated
 
 import cappa
-from falco.utils import get_current_dir_as_project_name
-from falco.utils import run_shell_command
+from falco.utils import get_project_name
+from falco.utils import run_in_shell
 from falco.utils import simple_progress
 from rich import print as rich_print
 
+from . import checks
+
 django_debug_value_code = """
 from django.conf import settings
 print(settings.DEBUG)
@@ -19,11 +21,24 @@ class RmMigrations:
         Path | None,
         cappa.Arg(default=None, help="The path to your django apps directory."),
     ]
+    skip_git_check: Annotated[
+        bool,
+        cappa.Arg(
+            default=False,
+            long="--skip-git-check",
+            help="Do not check if your git repo is clean.",
+        ),
+    ]
 
-    def __call__(self, project_name: Annotated[str, cappa.Dep(get_current_dir_as_project_name)]):
-        django_debug_value = run_shell_command(django_debug_value_code, eval_result=True)
+    def __call__(self, project_name: Annotated[str, cappa.Dep(get_project_name)]):
+        checks.clean_git_repo(ignore_dirty=self.skip_git_check)
+
+        django_debug_value = run_in_shell(django_debug_value_code, eval_result=True)
         if not django_debug_value:
-            raise cappa.Exit("This command can only be run with DEBUG=True.", code=1)
+            raise cappa.Exit(
+                "Nope, not happening, this command can only be run with DEBUG=True.",
+                code=1,
+            )
 
         if not self.apps_dir:
             self.apps_dir = Path() / project_name
