@@ -7,7 +7,7 @@ from typing import Annotated
 import cappa
 from dotenv import dotenv_values
 from dotenv import set_key
-from falco.utils import get_current_dir_as_project_name
+from falco.utils import get_project_name
 from rich import print as rich_print
 from rich.prompt import Prompt
 
@@ -24,15 +24,16 @@ class SyncDotenv:
         ),
     ]
 
-    def __call__(self, project_name: Annotated[str, cappa.Dep(get_current_dir_as_project_name)]):
+    def __call__(self, project_name: Annotated[str, cappa.Dep(get_project_name)]):
         dotenv_file = Path(".env")
         dotenv_template_file = Path(".env.template")
 
         default_values = {
             "DJANGO_DEBUG": True,
+            "DJANGO_ENV": "dev",
             "DJANGO_SECRET_KEY": secrets.token_urlsafe(64),
             "DJANGO_ALLOWED_HOSTS": "*",
-            "DATABASE_URL": f"postgres:///{project_name}",
+            "DATABASE_URL": "sqlite:///db.sqlite3",
             "DJANGO_SUPERUSER_EMAIL": "",
             "DJANGO_SUPERUSER_PASSWORD": "",
         }
@@ -49,7 +50,7 @@ class SyncDotenv:
                     config[key] = Prompt.ask(f"{key}")
             postgres_user = Prompt.ask("Postgres user", default="postgres")
             postgres_password = Prompt.ask("Postgres password", default="postgres")
-            config["DATABASE_URL"] = f"postgres://{postgres_user}:{postgres_password}@localhost:5432/{project_name}"
+            config["DATABASE_URL"] = f"postgres://{postgres_user}:{postgres_password}@127.0.0.1:5432/{project_name}"
 
         sorted_config = dict(sorted(config.items(), key=lambda x: str(x[0])))
 
@@ -68,7 +69,7 @@ class SyncDotenv:
         # empty and write to .env.template file
         original_values = dotenv_values(dotenv_template_file)
         dotenv_template_file.write_text("")
-        for key, value in sorted_config.items():
+        for key in sorted_config:
             set_key(
                 dotenv_template_file,
                 key,
